top10 = [
    {"character_id": 1001, "kill_count": 3, "character_name": "Gneuten"},
    {"character_id": 1002, "kill_count": 3, "character_name": "rotze Rotineque"},
    {"character_id": 1004, "kill_count": 1, "character_name": "Garthd"},
    {"character_id": 1005, "kill_count": 1, "character_name": "Gerthd"},
    {"character_id": 1010, "kill_count": 1, "character_name": "Test1"},
    {"character_id": 1011, "kill_count": 1, "character_name": "Test2"},
    {"character_id": 1012, "kill_count": 1, "character_name": "Test3"},
    {"character_id": 1013, "kill_count": 1, "character_name": "Test4"},
]

top10_alt = [
    {"character_id": 1001, "kill_count": 3, "character_name": "Gneuten"},
    {"character_id": 1002, "kill_count": 3, "character_name": "rotze Rotineque"},
    {"character_id": 1004, "kill_count": 1, "character_name": "Garthd (Gneuten)"},
    {"character_id": 1005, "kill_count": 1, "character_name": "Gerthd"},
    {"character_id": 1010, "kill_count": 1, "character_name": "Test1"},
    {"character_id": 1011, "kill_count": 1, "character_name": "Test2"},
    {"character_id": 1012, "kill_count": 1, "character_name": "Test3"},
    {"character_id": 1013, "kill_count": 1, "character_name": "Test4"},
]

top10_unknown = [
    {"character_id": 1001, "kill_count": 3, "character_name": "Unknown"},
    {"character_id": 1002, "kill_count": 3, "character_name": "Unknown"},
    {"character_id": 1004, "kill_count": 1, "character_name": "Unknown"},
    {"character_id": 1005, "kill_count": 1, "character_name": "Unknown"},
    {"character_id": 1010, "kill_count": 1, "character_name": "Unknown"},
    {"character_id": 1011, "kill_count": 1, "character_name": "Unknown"},
    {"character_id": 1012, "kill_count": 1, "character_name": "Unknown"},
    {"character_id": 1013, "kill_count": 1, "character_name": "Unknown"},
]
