{% load i18n %}
{% load navactive %}
<li class="nav-item">
    <a class="nav-link" href="{% url 'killstats:corporation_admin' %}">{% translate "Corporation Overview" %}</a>
</li>

<li class="nav-item">
    <a class="nav-link" href="{% url 'killstats:alliance_admin' %}">{% translate "Alliance Overview" %}</a>
</li>
