<div class="card" id="hall" style="display: none;">
	<div class="rounded-top" style="--bs-bg-opacity: .5;">
        <ul class="nav nav-tabs" id="killstats-killmail-hallof">

            <li class="nav-item" id="shame-nav">
                <a class="nav-link bg-secondary rounded-top active" href="#tab-shame" data-bs-toggle="tab" data-bs-target="#tab-shame" >
                    Hall of Shame
                </a>
            </li>

            <li class="nav-item" id="fame-nav">
                <a class="nav-link bg-secondary rounded-top" href="#tab-fame" data-bs-toggle="tab" data-bs-target="#tab-fame">
                    Hall of Fame
                </a>
            </li>

        </ul>
    </div>
    <div class="bg-secondary tab-content">
        <!--Hall of Shame-->
        <div id="tab-shame" class="tab-pane active">
            <div class="panel-body">
                <div class="charactercards">
                    <ul class="cards_container">
                    </ul>
                </div>
            </div>
        </div>
        <!--Hall of Fame-->
        <div id="tab-fame" class="tab-pane">
            <div class="panel-body">
                <div class="charactercards">
                    <ul class="cards_container">
                    </ul>
                </div>
            </div>
        </div>

    </div>
</div>
