# Generated by Django 4.2.11 on 2024-11-22 17:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("killstats", "0005_alter_general_options"),
    ]

    operations = [
        migrations.AlterField(
            model_name="attacker",
            name="weapon_type_id",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="killmail",
            name="killmail_date",
            field=models.DateTimeField(blank=True, max_length=0, null=True),
        ),
        migrations.AlterField(
            model_name="killmail",
            name="killmail_id",
            field=models.PositiveIntegerField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name="killmail",
            name="victim_alliance_id",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="killmail",
            name="victim_corporation_id",
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterField(
            model_name="killmail",
            name="victim_region_id",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="killmail",
            name="victim_solar_system_id",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
