{% load i18n %}
{% load humanize %}

<div role="tabpanel" class="tab-pane active" id="tab-kills">
    <div class="table-responsive">
        <div class="text-center">
            <h3 class="fw-bold">Total Value: <span id="total-value-kills">{{ total.totalValue }}</span> ISK</h3>
        </div>
        <table class="table table-striped table-hover killmail w-100" id="kills">
            <thead>
                <tr>
                    <th class="col-killmail" style="width: 5%;"></th>
                    <th class="col-type" style="width: 20%;">Type</th>
                    <th class="col-portrait" style="width: 5%;"></th>
                    <th class="col-character" style="width: 20%;">Character</th>
                    <th class="col-totalvalue" style="width: 20%;">Total Value</th>
                    <th class="col-date" style="width: 20%;">Date</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td class="col-killmail"></td>
                    <td class="col-type"></td>
                    <td class="col-portrait"></td>
                    <td class="col-character"></td>
                    <td class="col-totalvalue"></td>
                    <td class="col-date"></td>
                </tr>
            </tbody>
        </table>
    </div>
</div>
