Killstats_Stats = [{"stats": []}]

Killstats_Stats_Entry = [
    {
        "stats": [
            {
                "killmail_id": 119303073,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "corporation_id": 20000001,
                "alliance_id": 30000001,
                "ship": 10001,
                "ship_name": "Victim Ship I",
                "hash": "VictimHash2",
                "totalValue": 94395699,
                "date": "2024-07-07T21:36:58+00:00",
                "title": "Top Loss:",
                "portrait": "https://images.evetech.net/types/10001/icon?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
            },
            {
                "title": "Worst Ship:",
                "type": "count",
                "ship_id": 10001,
                "ship_name": "Victim Ship I",
                "portrait": "https://images.evetech.net/types/10001/icon?size=256",
                "count": 2,
                "loss": True,
                "zkb_link": "https://zkillboard.com/ship/10001/",
            },
            {
                "title": "Top Victim: Garthd",
                "type": "count",
                "character_id": 1004,
                "character_name": "Garthd",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "count": 1,
                "loss": True,
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "title": "Alltime Victim: Garthd",
                "type": "count",
                "character_id": 1004,
                "character_name": "Garthd",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "count": 1,
                "loss": True,
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "killmail_id": 119303075,
                "character_id": 1004,
                "character_name": "Garthd",
                "corporation_id": 20000001,
                "alliance_id": 30000001,
                "ship": 10002,
                "ship_name": "Victim Ship II",
                "hash": "VictimHash3",
                "totalValue": 9999,
                "date": "2024-07-07T21:38:58+00:00",
                "title": "Top Kill:",
                "portrait": "https://images.evetech.net/types/10002/icon?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "title": "Top Ship:",
                "type": "count",
                "ship_id": 20002,
                "ship_name": "Attacker Ship II",
                "portrait": "https://images.evetech.net/types/20002/icon?size=256",
                "count": 10,
                "loss": False,
                "zkb_link": "https://zkillboard.com/ship/20002/",
            },
            {
                "title": "Top Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 3,
                "loss": False,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "title": "Alltime Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 3,
                "loss": False,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
        ]
    }
]

Killstats_Stats_Single = [
    {
        "stats": [
            {
                "killmail_id": 119303073,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "corporation_id": 20000001,
                "alliance_id": 30000001,
                "ship": 10001,
                "ship_name": "Victim Ship I",
                "hash": "VictimHash2",
                "totalValue": 94395699,
                "date": "2024-07-07T21:36:58+00:00",
                "title": "Top Loss:",
                "portrait": "https://images.evetech.net/types/10001/icon?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
            },
            {
                "title": "Worst Ship:",
                "type": "count",
                "ship_id": 10001,
                "ship_name": "Victim Ship I",
                "portrait": "https://images.evetech.net/types/10001/icon?size=256",
                "count": 2,
                "loss": True,
                "zkb_link": "https://zkillboard.com/ship/10001/",
            },
            {
                "title": "Top Victim: Garthd",
                "type": "count",
                "character_id": 1004,
                "character_name": "Garthd",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "count": 1,
                "loss": True,
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "title": "Alltime Victim: Garthd",
                "type": "count",
                "character_id": 1004,
                "character_name": "Garthd",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "count": 1,
                "loss": True,
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "killmail_id": 119303075,
                "character_id": 1004,
                "character_name": "Garthd",
                "corporation_id": 20000001,
                "alliance_id": 30000001,
                "ship": 10002,
                "ship_name": "Victim Ship II",
                "hash": "VictimHash3",
                "totalValue": 9999,
                "date": "2024-07-07T21:38:58+00:00",
                "title": "Top Kill:",
                "portrait": "https://images.evetech.net/types/10002/icon?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "title": "Top Ship:",
                "type": "count",
                "ship_id": 20002,
                "ship_name": "Attacker Ship II",
                "portrait": "https://images.evetech.net/types/20002/icon?size=256",
                "count": 10,
                "loss": False,
                "zkb_link": "https://zkillboard.com/ship/20002/",
            },
            {
                "title": "Top Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 3,
                "loss": False,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "title": "Alltime Killer: Gneuten",
                "type": "count",
                "character_id": 1001,
                "character_name": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "count": 3,
                "loss": False,
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
        ]
    }
]


Killstats_Halls_Entry = [
    {
        "shame": [
            {
                "killmail_id": 119303073,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "ship": 10001,
                "ship_name": "Victim Ship I",
                "totalValue": 94395699,
                "title": "rotze Rotineque",
                "portrait": "https://images.evetech.net/characters/1002/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
            },
            {
                "killmail_id": 119303113,
                "character_id": 1001,
                "character_name": "Gneuten",
                "ship": 10001,
                "ship_name": "Victim Ship I",
                "totalValue": 76734851,
                "title": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "killmail_id": 119303075,
                "character_id": 1004,
                "character_name": "Garthd",
                "ship": 10002,
                "ship_name": "Victim Ship II",
                "totalValue": 9999,
                "title": "Garthd",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
        ],
        "fame": [
            {
                "killmail_id": 119303075,
                "character_id": 1001,
                "character_name": "Gneuten",
                "ship": 10002,
                "ship_name": "Victim Ship II",
                "totalValue": 9999,
                "title": "Garthd",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "killmail_id": 1,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1002/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
            },
            {
                "killmail_id": 2,
                "character_id": 1004,
                "character_name": "Garthd",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "killmail_id": 3,
                "character_id": 1012,
                "character_name": "Test3",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1012/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1012/",
            },
            {
                "killmail_id": 4,
                "character_id": 1010,
                "character_name": "Test1",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1010/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1010/",
            },
        ],
    }
]

Killstats_Halls_Single = [
    {
        "shame": [
            {
                "killmail_id": 119303073,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "ship": 10001,
                "ship_name": "Victim Ship I",
                "totalValue": 94395699,
                "title": "rotze Rotineque",
                "portrait": "https://images.evetech.net/characters/1002/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
            },
            {
                "killmail_id": 119303113,
                "character_id": 1001,
                "character_name": "Gneuten",
                "ship": 10001,
                "ship_name": "Victim Ship I",
                "totalValue": 76734851,
                "title": "Gneuten",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "killmail_id": 119303075,
                "character_id": 1004,
                "character_name": "Garthd",
                "ship": 10002,
                "ship_name": "Victim Ship II",
                "totalValue": 9999,
                "title": "Garthd",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
        ],
        "fame": [
            {
                "killmail_id": 119303075,
                "character_id": 1001,
                "character_name": "Gneuten",
                "ship": 10002,
                "ship_name": "Victim Ship II",
                "totalValue": 9999,
                "title": "Garthd",
                "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1001/",
            },
            {
                "killmail_id": 1,
                "character_id": 1002,
                "character_name": "rotze Rotineque",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1002/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1002/",
            },
            {
                "killmail_id": 2,
                "character_id": 1004,
                "character_name": "Garthd",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1004/",
            },
            {
                "killmail_id": 3,
                "character_id": 1012,
                "character_name": "Test3",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1012/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1012/",
            },
            {
                "killmail_id": 4,
                "character_id": 1010,
                "character_name": "Test1",
                "ship": 10003,
                "ship_name": "Victim Ship III",
                "totalValue": 1000,
                "title": "CONCORD",
                "portrait": "https://images.evetech.net/characters/1010/portrait?size=256",
                "zkb_link": "https://zkillboard.com/character/1010/",
            },
        ],
    }
]

Killstats_Kills_Entry = {
    "draw": 1,
    "recordsTotal": 6,
    "recordsFiltered": 6,
    "data": [
        {
            "killmail_id": 119303077,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1000, "name": "CONCORD"},
            "victim_ship": {"id": 10003, "name": "Victim Ship III"},
            "victim_corporation_id": 1000125,
            "victim_alliance_id": None,
            "hash": "AttackerHash1",
            "victim_total_value": 1000,
            "victim_fitted_value": 2000,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
        {
            "killmail_id": 119303075,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1004, "name": "Garthd"},
            "victim_ship": {"id": 10002, "name": "Victim Ship II"},
            "victim_corporation_id": 20000001,
            "victim_alliance_id": 30000001,
            "hash": "VictimHash3",
            "victim_total_value": 9999,
            "victim_fitted_value": 9888,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
        {
            "killmail_id": 4,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1000, "name": "CONCORD"},
            "victim_ship": {"id": 10003, "name": "Victim Ship III"},
            "victim_corporation_id": 1000125,
            "victim_alliance_id": None,
            "hash": "AttackerHash5",
            "victim_total_value": 1000,
            "victim_fitted_value": 2000,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
        {
            "killmail_id": 3,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1000, "name": "CONCORD"},
            "victim_ship": {"id": 10003, "name": "Victim Ship III"},
            "victim_corporation_id": 1000125,
            "victim_alliance_id": None,
            "hash": "AttackerHash4",
            "victim_total_value": 1000,
            "victim_fitted_value": 2000,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
        {
            "killmail_id": 2,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1000, "name": "CONCORD"},
            "victim_ship": {"id": 10003, "name": "Victim Ship III"},
            "victim_corporation_id": 1000125,
            "victim_alliance_id": None,
            "hash": "AttackerHash3",
            "victim_total_value": 1000,
            "victim_fitted_value": 2000,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
        {
            "killmail_id": 1,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1000, "name": "CONCORD"},
            "victim_ship": {"id": 10003, "name": "Victim Ship III"},
            "victim_corporation_id": 1000125,
            "victim_alliance_id": None,
            "hash": "AttackerHash2",
            "victim_total_value": 1000,
            "victim_fitted_value": 2000,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
    ],
    "totalvalue": [14999],
}

Killstats_Losses_Entry = {
    "draw": 1,
    "recordsTotal": 3,
    "recordsFiltered": 3,
    "data": [
        {
            "killmail_id": 119303113,
            "killmail_date": "2024-07-07T21:38:59Z",
            "victim": {"id": 1001, "name": "Gneuten"},
            "victim_ship": {"id": 10001, "name": "Victim Ship I"},
            "victim_corporation_id": 20000001,
            "victim_alliance_id": 30000001,
            "hash": "VictimHash1",
            "victim_total_value": 76734851,
            "victim_fitted_value": 72603992,
            "victim_destroyed_value": 64460362,
            "victim_dropped_value": 12274488,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459026975.88434,
            "victim_position_y": -4921955322.159037,
            "victim_position_z": -8888754631.141735,
        },
        {
            "killmail_id": 119303075,
            "killmail_date": "2024-07-07T21:38:58Z",
            "victim": {"id": 1004, "name": "Garthd"},
            "victim_ship": {"id": 10002, "name": "Victim Ship II"},
            "victim_corporation_id": 20000001,
            "victim_alliance_id": 30000001,
            "hash": "VictimHash3",
            "victim_total_value": 9999,
            "victim_fitted_value": 9888,
            "victim_destroyed_value": 3000,
            "victim_dropped_value": 1000,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
        {
            "killmail_id": 119303073,
            "killmail_date": "2024-07-07T21:36:58Z",
            "victim": {"id": 1002, "name": "rotze Rotineque"},
            "victim_ship": {"id": 10001, "name": "Victim Ship I"},
            "victim_corporation_id": 20000001,
            "victim_alliance_id": 30000001,
            "hash": "VictimHash2",
            "victim_total_value": 94395699,
            "victim_fitted_value": 80172608,
            "victim_destroyed_value": 87869532,
            "victim_dropped_value": 6526166,
            "victim_region_id": 10000059,
            "victim_solar_system_id": 30004668,
            "victim_position_x": -74459258618.29333,
            "victim_position_y": -4921962525.529236,
            "victim_position_z": -8888733393.073042,
        },
    ],
    "totalvalue": [171140549],
}
