<div class="stats d-flex justify-content-center">
    <div id="stats" class="row row-cols-4" style="width: 1600px;">
        <div id="stat-template" class="mb-2" style="display: none;">
            <div class="row g-0 bg-secondary rounded">
                <div class="col-md-4">
                    <a href="" target="_blank" class="stat-link">
                        <img class="card-img-zoom img-fluid rounded-start w-100 h-100 stat-portrait" src="">
                    </a>
                </div>
                <div class="col-md-8 px-2 py-2">
                    <div class="card-body">
                        <h5 class="card-title text-truncate stat-title"></h5>
                        <p class="text-truncate stat-info"></p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
