top_ship = [
    {
        "stats": {
            "title": "Top Ship:",
            "type": "count",
            "ship_id": 20002,
            "ship_name": "Attacker Ship II",
            "portrait": "https://images.evetech.net/types/20002/icon?size=256",
            "count": 5,
            "loss": False,
            "zkb_link": "https://zkillboard.com/ship/20002/",
        }
    }
]

worst_ship = [
    {
        "stats": {
            "title": "Worst Ship:",
            "type": "count",
            "ship_id": 10001,
            "ship_name": "Victim Ship I",
            "portrait": "https://images.evetech.net/types/10001/icon?size=256",
            "count": 2,
            "loss": True,
            "zkb_link": "https://zkillboard.com/ship/10001/",
        }
    }
]

top_killer = [
    {
        "stats": {
            "title": "Top Killer: Gneuten",
            "type": "count",
            "character_id": 1001,
            "character_name": "Gneuten",
            "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
            "count": 3,
            "loss": False,
            "zkb_link": "https://zkillboard.com/character/1001/",
        }
    }
]

top_victim = [
    {
        "stats": {
            "title": "Top Victim: Garthd",
            "type": "count",
            "character_id": 1004,
            "character_name": "Garthd",
            "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
            "count": 1,
            "loss": False,
            "zkb_link": "https://zkillboard.com/character/1004/",
        }
    }
]

top_kill = [
    {
        "stats": {
            "killmail_id": 119303075,
            "character_id": 1004,
            "character_name": "Garthd",
            "corporation_id": 20000001,
            "alliance_id": 30000001,
            "ship": 10002,
            "ship_name": "Victim Ship II",
            "hash": "VictimHash3",
            "totalValue": 9999,
            "date": "2024-07-07T21:38:58+00:00",
            "title": "Top Kill:",
            "portrait": "https://images.evetech.net/types/10002/icon?size=256",
            "zkb_link": "https://zkillboard.com/kill/119303075/",
        }
    }
]

top_loss = [
    {
        "stats": {
            "killmail_id": 119303073,
            "character_id": 1002,
            "character_name": "rotze Rotineque",
            "corporation_id": 20000001,
            "alliance_id": 30000001,
            "ship": 10001,
            "ship_name": "Victim Ship I",
            "hash": "VictimHash2",
            "totalValue": 94395699,
            "date": "2024-07-07T21:36:58+00:00",
            "title": "Top Loss:",
            "portrait": "https://images.evetech.net/types/10001/icon?size=256",
            "zkb_link": "https://zkillboard.com/kill/119303073/",
        }
    }
]

alltime_killer = [
    {
        "stats": {
            "title": "Alltime Killer: Gneuten",
            "type": "count",
            "character_id": 1001,
            "character_name": "Gneuten",
            "portrait": "https://images.evetech.net/characters/1001/portrait?size=256",
            "count": 3,
            "loss": False,
            "zkb_link": "https://zkillboard.com/character/1001/",
        }
    }
]

alltime_victim = [
    {
        "stats": {
            "title": "Alltime Victim: Garthd",
            "type": "count",
            "character_id": 1004,
            "character_name": "Garthd",
            "portrait": "https://images.evetech.net/characters/1004/portrait?size=256",
            "count": 1,
            "loss": False,
            "zkb_link": "https://zkillboard.com/character/1004/",
        }
    }
]
